@@ -86,8 +86,8 @@ class Spec:
                     prop = {}
 
                     pSchema, pUISchema = {}, {}
-                    pSchema.title = 'Input'
-                    pSchema.type = 'object'
+                    pSchema['title'] = 'Input'
+                    pSchema['type'] = 'object'
 
                     inProperties, formData = {}, {}
                     uiOrder = []
@@ -152,8 +152,8 @@ class Spec:
                     prop = {}
 
                     pSchema, pUISchema = {}, {}
-                    pSchema.title = 'Output'
-                    pSchema.type = 'object'
+                    pSchema['title'] = 'Output'
+                    pSchema['type'] = 'object'
 
                     outProperties, formData = {}, {}
                     uiOrder = []
@@ -214,8 +214,8 @@ class Spec:
                     prop = {}
 
                     pSchema, pUISchema = {}, {}
-                    pSchema.title = 'Options'
-                    pSchema.type = 'object'
+                    pSchema['title'] = 'Options'
+                    pSchema['type'] = 'object'
 
                     optProperties, formData = {}, {}
                     uiOrder = []
